# Fetch Azure Kubernetes Services credentials 

This is a program which is responsible to fetch the AKS credentials using azure-cli.

## Installing the package

```
pip install az_creds
```

## Dependencies 
  - azure-cli

```
# for debian based systems
sudo apt-get install azure-cli

# for rpm based systems
sudo yum install azure-cli
```

## Usage:

Open your terminal and run the following command:

```
az_creds
```



